@@ -1,7 +1,7 @@
 /*
    This file is part of the Nepomuk KDE project.
    Copyright (C) 2011 Sebastian Trueg <trueg@kde.org>
-   Copyright (C) 2011 Vishesh Handa <handa.vish@gmail.com>
+   Copyright (C) 2011-12 Vishesh Handa <handa.vish@gmail.com>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,7 @@
 
 #include "resourcewatchertest.h"
 #include "../datamanagementmodel.h"
+#include "../virtuosoinferencemodel.h"
 #include "../classandpropertytree.h"
 #include "../resourcewatcherconnection.h"
 #include "../resourcewatchermanager.h"
@@ -47,6 +48,7 @@
 #include "nmm.h"
 #include "nco.h"
 #include "nie.h"
+#include "pimo.h"
 #include "resourcemanager.h"
 
 using namespace Soprano;
@@ -80,7 +82,8 @@ void ResourceWatcherTest::initTestCase()
     // DataManagementModel relies on the ussage of a NRLModel in the storage service
     m_nrlModel = new Soprano::NRLModel(m_model);
     m_classAndPropertyTree = new Nepomuk2::ClassAndPropertyTree(this);
-    m_dmModel = new Nepomuk2::DataManagementModel(m_classAndPropertyTree, m_nrlModel);
+    m_inferenceModel = new Nepomuk2::VirtuosoInferenceModel(m_nrlModel);
+    m_dmModel = new Nepomuk2::DataManagementModel(m_classAndPropertyTree, m_inferenceModel);
 }
 
 void ResourceWatcherTest::cleanupTestCase()
@@ -1193,6 +1196,82 @@ void ResourceWatcherTest::testRemoveProperty_typeRemoved()
 
 void ResourceWatcherTest::testMergeResources()
 {
+    SimpleResource tom;
+    tom.addType( NCO::Contact() );
+    tom.addProperty( NCO::fullname(), QLatin1String("Tom Marvolo Riddle") );
+
+    SimpleResource voldemort;
+    voldemort.addType( NCO::Contact() );
+    voldemort.addProperty( NCO::fullname(), QLatin1String("Lord Voldemort") );
+    voldemort.addProperty( NCO::gender(), NCO::male() );
+
+    SimpleResource person;
+    person.addType( PIMO::Person() );
+    person.addProperty( PIMO::groundingOccurrence(), tom );
+    person.addProperty( PIMO::groundingOccurrence(), voldemort );
+
+    SimpleResourceGraph graph;
+    graph << tom << voldemort << person;
+
+    QHash<QUrl, QUrl> mappings = m_dmModel->storeResources( graph, QLatin1String("app") );
+    QVERIFY(!m_dmModel->lastError());
+
+    ResourceWatcherConnection* cWatcher = m_dmModel->resourceWatcherManager()->createConnection(
+                                     QList<QUrl>(), QList<QUrl>(), QList<QUrl>() << NCO::Contact() );
+    QSignalSpy wAddSpy(cWatcher, SIGNAL(propertyAdded(QString, QString, QVariantList)));
+    QSignalSpy wChSpy(cWatcher, SIGNAL(propertyChanged(QString, QString, QVariantList, QVariantList)));
+    QSignalSpy wRemoveSpy(cWatcher, SIGNAL(resourceRemoved(QString, QStringList)));
+
+    ResourceWatcherConnection* pWatcher = m_dmModel->resourceWatcherManager()->createConnection(
+                                    QList<QUrl>(), QList<QUrl>(), QList<QUrl>() << PIMO::Person() );
+    QSignalSpy personCreateSpy(pWatcher, SIGNAL(resourceCreated(QString, QStringList)));
+    QSignalSpy personPropRemoveSpy(pWatcher, SIGNAL(propertyRemoved(QString, QString, QVariantList)));
+    QSignalSpy personPropChangeSpy(pWatcher, SIGNAL(propertyChanged(QString, QString, QVariantList, QVariantList)));
+
+    const QUrl tomUri = mappings.value( tom.uri() );
+    const QUrl voldUri = mappings.value( voldemort.uri() );
+    const QUrl personUri = mappings.value( person.uri() );
+
+    m_dmModel->mergeResources( QList<QUrl>()<< tomUri << voldUri, QLatin1String("app") );
+    QTest::qSleep( 100 );
+
+    QCOMPARE( wAddSpy.count(), 1 );
+    QVariantList args = wAddSpy.takeFirst();
+    QCOMPARE( args[0].toUrl(), tomUri );
+    QCOMPARE( args[1].toUrl(), NCO::gender() );
+    QCOMPARE( args[2].toList().size(), 1 );
+    QCOMPARE( args[2].toList().first().toUrl(), NCO::male() );
+
+    QCOMPARE( wChSpy.count(), 1 );
+    args = wChSpy.takeFirst();
+    QCOMPARE( args[0].toUrl(), tomUri );
+    QCOMPARE( args[1].toUrl(), NCO::gender() );
+    QCOMPARE( args[2].toList().size(), 1 );
+    QCOMPARE( args[2].toList().first().toUrl(), NCO::male() );
+    QCOMPARE( args[3].toList().size(), 0 );
+
+    QCOMPARE( wRemoveSpy.count(), 1 );
+    args = wRemoveSpy.takeFirst();
+    QCOMPARE( args[0].toUrl(), voldUri );
+    QCOMPARE( args[1].toList().size(), 1 );
+    QCOMPARE( args[1].toList().first().toUrl(), NCO::Contact() );
+
+    QCOMPARE( personCreateSpy.count(), 0 );
+
+    QCOMPARE( personPropChangeSpy.count(), 1 );
+    args = personPropChangeSpy.takeFirst();
+    QCOMPARE( args[0].toUrl(), personUri );
+    QCOMPARE( args[1].toUrl(), PIMO::groundingOccurrence() );
+    QCOMPARE( args[2].toList().size(), 0 );
+    QCOMPARE( args[3].toList().size(), 1 );
+    QCOMPARE( args[3].toList().first().toUrl(), voldUri );
+
+    QCOMPARE( personPropRemoveSpy.count(), 1 );
+    args = personPropRemoveSpy.takeFirst();
+    QCOMPARE( args[0].toUrl(), personUri );
+    QCOMPARE( args[1].toUrl(), PIMO::groundingOccurrence() );
+    QCOMPARE( args[2].toList().size(), 1 );
+    QCOMPARE( args[2].toList().first().toUrl(), voldUri );
 }
 
 
